@@ -1,6 +1,6 @@
 {-|
 Module      : Text.Jira.Parser
-Copyright   : © 2019–2020 Albert Krewinkel
+Copyright   : © 2019–2023 Albert Krewinkel
 License     : MIT
 
 Maintainer  : Albert Krewinkel <tarleb@zeitkraut.de>
@@ -33,4 +33,4 @@ parse = parseJira doc
 
 -- | Parses a list of jira blocks into a @'Doc'@ element.
 doc :: JiraParser Doc
-doc = Doc <$> many block <?> "doc"
+doc = Doc <$> (skipMany blankline *> many block) <?> "doc"
