@@ -1,6 +1,6 @@
 {-|
 Module      : Text.Jira.ParserTests
-Copyright   : © 2019–2020 Albert Krewinkel
+Copyright   : © 2019–2023 Albert Krewinkel
 License     : MIT
 
 Maintainer  : Albert Krewinkel <tarleb@zeitkraut.de>
@@ -31,6 +31,10 @@ tests = testGroup "Parser"
       parse "h1. test\nThis is ok." @?=
       Right (Doc [ Header 1 [Str "test"]
                  , Para [Str "This", Space, Str "is", Space, Str "ok."]])
+
+    , testCase "leading blank lines" $
+      parse "\n\ntext\n" @?=
+      Right (Doc [Para [Str "text"]])
     ]
 
   , testGroup "plainText"
@@ -46,10 +50,23 @@ tests = testGroup "Parser"
       plainText ":)" @?=
       Right [Str "\\:)"]
 
+    , testCase "smiley and text" $
+      plainText ":D lol" @?=
+      Right [Str "\\:D", Space, Str "lol"]
+
     , testCase "icon after word" $
       plainText "f(x)" @?=
       Right [Str "f\\(x)"]
 
+    , testCase "icon-sequence at start of word" $
+      plainText ":PA" @?=
+      Right [SpecialChar ':', Str "PA"]
+
+    , testCase "icon-sequence followed by digit" $
+      plainText ":P2" @?=
+      Right [SpecialChar ':', Str "P2"]
+
+
     , testCase "special chars" $
       plainText "*not strong*" @?=
       Right [SpecialChar '*', Str "not", Space, Str "strong", SpecialChar '*']
